require "rest-client"
require "json"
require "launchy"
require "highline"

module Zapnito
  module Cli
    module Commands
      class Environment < Thor
        desc "publish", "publishes the theme in the current directory"
        def publish
          theme = Services.local.load
          puts "---> Publishing #{theme.tenant_slug}"

          release_config = zapnito.s3_upload_urls_for_theme(theme)
          Services.s3.upload_theme(theme, release_config)
          zapnito.build_release(theme)

          puts "---> Published #{theme.tenant_slug}/#{theme.revision}"
        rescue Exception => e
          if e.try(:response).try(:code) == 406
            show_sass_error(e)
          else
            raise e
          end
        end

        desc "preview_link", "show preview link for current theme"
        def preview_link
          theme = Services.local.load
          link = zapnito.preview_link(theme)
          puts "---> #{link}"
        end

        desc "preview", "preview current theme in browser"
        def preview
          theme = Services.local.load
          link = zapnito.preview_link(theme)
          puts "link: #{link}"
          Launchy.open(link)
        end

        private

        def zapnito
          Services.zapnito(api_token, basepath)
        end

        def show_sass_error(e)
          error = JSON.parse(e.response)["error"]
          puts "---! #{error["message"]}"
          puts "=========================="
          puts "---! #{error["sass_backtrace"]}"
        end

        def api_token
          configatron.environments[environment].api_token!
        end

        def basepath
          configatron.environments[environment].basepath!
        end

        def environment
          raise "not implemented"
        end
      end
    end
  end
end
