module Zapnito
  module Cli
    module Models
      class Theme
        attr_reader :tenant_slug, :revision, :files

        def initialize(path)
          @path = with_trailing_slash(path)

          @tenant_slug = File.basename(path)
          @revision = build_revision(@path)
          @files = build_files(@path)
        end

        def absolute_path_for(file)
          File.join(@path, file)
        end

        def mime_type_for(file)
          Utils.mime_type_for(file)
        end

        private

        def with_trailing_slash(text)
          text.gsub(/([^\/]{1,1})$/, '\1/')
        end

        def build_files(theme_path)
          absolute_paths = Dir[File.join(theme_path, '**', '*')]
          absolute_file_paths = absolute_paths.reject { |path| FileTest.directory?(path) }
          absolute_file_paths.map { |path| path.gsub(theme_path, "") }
        end

        def build_revision(theme_path)
          Utils.checksum_directory(theme_path)
        end
      end
    end
  end
end
