module Zapnito
  module Cli
    module Services
      class Zapnito
        def initialize(api_token, basepath)
          @api_token = api_token
          @basepath = basepath
        end

        def tenant_slugs
          tenants = get_json("/theme_tenants.json")["tenants"]
          tenants.map { |t| t["slug"] }.sort
        end

        def s3_upload_urls_for_theme(theme)
          post_json("/themes/#{theme.tenant_slug}/uploads", build_payload(theme))
        end

        def build_release(theme)
          put_json("/themes/#{theme.tenant_slug}/releases/#{theme.revision}")
        end

        def preview_link(theme)
          url("/themes/#{theme.tenant_slug}/previews/#{theme.revision}")
        end

        private

        def build_payload(theme)
          JSON.dump({
            revision: theme.revision,
            resources: theme.files.each_with_object({}) do |theme_file, resources|
              resources[theme_file] = { "contentType" => theme.mime_type_for(theme_file) }
            end
          })
        end

        def put_json(path)
          RestClient.put(
            url(path),
            nil,
            content_type: :json,
            accept: :json,
            "AUTHORIZATION" => authorization_header
          )
        end

        def get_json(path)
          response = RestClient.get(
            url(path),
            content_type: :json,
            accept: :json,
            "AUTHORIZATION" => authorization_header
          )

          JSON.parse(response)
        end

        def post_json(path, payload)
          response = RestClient.post(
            url(path),
            payload,
            content_type: :json,
            accept: :json,
            "AUTHORIZATION" => authorization_header
          )

          JSON.parse(response)
        end

        def authorization_header
          "Token token=\"#{@api_token}\""
        end

        def url(path)
          "#{@basepath}#{path}"
        end
      end
    end
  end
end
